# The _ssos_ Pipeline
---
[![Documentation Status](https://readthedocs.org/projects/ssos/badge/?version=latest)](https://ssos.readthedocs.io/en/latest/?badge=latest) <a href="http://ascl.net/1901.006"><img src="https://img.shields.io/badge/ascl-1901.006-blue.svg?colorB=262255" alt="ascl:1901.006" /></a>

Pipeline to detect, identify, and recover Solar System Objects in astronomical images.

The online documentation is available at https://ssos.readthedocs.io/en/latest/

An article describing the high-level design of the pipeline is in preparation. In the meantime, if you have used the _ssos_ pipeline in your research, please reference

_Mahlke M., et al 2018, The ssos Pipeline, 1.2.1, Astrophysics Source Code Library ascl:1901.006_

Licensed under version 3 of the GNU Affero General Public License.